import { Request, Response } from '@alinea/iso';
import { Auth } from 'alinea/core/Auth';
import { Config } from 'alinea/core/Config';
import { Connection } from 'alinea/core/Connection';
import { EntryPhase } from 'alinea/core/EntryRow';
import { PreviewUpdate, ResolveRequest, Resolver } from 'alinea/core/Resolver';
import { Database } from './Database.js';
import { Drafts } from './Drafts.js';
import { History } from './History.js';
import { Media } from './Media.js';
import { Pending } from './Pending.js';
import { Previews } from './Previews';
import { Target } from './Target.js';
import { ChangeSetCreator } from './data/ChangeSet.js';
import { EntryResolver } from './resolver/EntryResolver.js';
import { Route } from './router/Router.js';
export interface HandlerOptions {
    config: Config;
    db: Database;
    previews: Previews;
    previewAuthToken: string;
    auth?: Auth.Server;
    target?: Target;
    media?: Media;
    drafts?: Drafts;
    history?: History;
    pending?: Pending;
    resolveDefaults?: Partial<ResolveRequest>;
}
export declare class Handler implements Resolver {
    options: HandlerOptions;
    connect: (ctx: Connection.Context) => Connection;
    router: Route<Request, Response | undefined>;
    changes: ChangeSetCreator;
    protected lastSync: number;
    protected resolver: EntryResolver;
    constructor(options: HandlerOptions);
    resolve: (params: ResolveRequest) => Promise<unknown>;
    protected previewAuth(): Connection.Context;
    parsePreview(preview: PreviewUpdate): Promise<{
        path: string;
        title: any;
        data: Record<string, any>;
        entryId: string;
        phase: EntryPhase;
        type: string;
        seeded: string | null;
        workspace: string;
        root: string;
        index: string;
        parent: string | null;
        i18nId: string;
        locale: string | null;
        active: boolean;
        main: boolean;
        level: number;
        filePath: string;
        parentDir: string;
        childrenDir: string;
        modifiedAt: number;
        rowHash: string;
        fileHash: string;
        url: string;
        searchableText: string;
    } | undefined>;
    periodicSync(syncInterval?: number): Promise<void>;
    syncPending(): Promise<{
        commitHash: string;
        contentHash: string;
        modifiedAt: number;
    }>;
}
