import "../chunks/chunk-U5RRZUYZ.js";

// src/cli/Generate.ts
import { exportStore } from "alinea/cli/util/ExportStore.server";
import { join } from "alinea/core/util/Paths";
import fs from "node:fs";
import { createRequire } from "node:module";
import path from "node:path";
import { compileConfig } from "./generate/CompileConfig.js";
import { copyStaticFiles } from "./generate/CopyStaticFiles.js";
import { fillCache } from "./generate/FillCache.js";
import { generateDashboard } from "./generate/GenerateDashboard.js";
import { loadCMS } from "./generate/LoadConfig.js";
import { LocalData } from "./generate/LocalData.js";
import { dirname } from "./util/Dirname.js";
import { findConfigFile } from "./util/FindConfigFile.js";
var __dirname = dirname(import.meta.url);
var require2 = createRequire(import.meta.url);
var alineaPackageDir = path.dirname(require2.resolve("alinea/package.json"));
function generatePackage(context, config) {
  const dashboard = config.dashboard;
  if (dashboard?.staticFile)
    return generateDashboard(
      context,
      dashboard.handlerUrl,
      dashboard.staticFile
    );
}
async function createDb() {
  const { default: sqlite } = await import("@alinea/sqlite-wasm");
  const { Database } = await sqlite();
  const { connect } = await import("../chunks/sql.js-RSY2XONK.js");
  const db = new Database();
  const store = connect(db).toAsync();
  return [store, () => db.export()];
}
async function* generate(options) {
  const {
    wasmCache = false,
    cwd = process.cwd(),
    configFile,
    staticDir = path.join(__dirname, "static"),
    quiet = false,
    onAfterGenerate
  } = options;
  const configLocation = configFile ? path.join(path.resolve(cwd), configFile) : findConfigFile(cwd);
  if (!configLocation)
    throw new Error(`No config file specified`);
  const rootDir = path.resolve(cwd);
  const configDir = path.dirname(configLocation);
  const nodeModules = alineaPackageDir.includes("node_modules") ? path.join(alineaPackageDir, "..") : path.join(alineaPackageDir, "node_modules");
  const context = {
    wasmCache,
    rootDir,
    staticDir,
    quiet,
    configDir,
    configLocation,
    fix: options.fix || false,
    outDir: path.join(nodeModules, "@alinea/generated"),
    // path.join(rootDir, '.alinea'),
    watch: options.watch || false
  };
  await copyStaticFiles(context);
  const builds = compileConfig(context)[Symbol.asyncIterator]();
  let nextBuild = builds.next();
  let afterGenerateCalled = false;
  function writeStore(data) {
    return exportStore(data, join(context.outDir, "store.js"));
  }
  const [store, storeData] = await createDb();
  while (true) {
    const { done } = await nextBuild;
    nextBuild = builds.next();
    try {
      const cms = await loadCMS(context.outDir);
      await writeStore(new Uint8Array());
      const fileData = new LocalData({
        config: cms.config,
        fs: fs.promises,
        rootDir,
        dashboardUrl: await options.dashboardUrl
      });
      for await (const db of fillCache(
        context,
        fileData,
        store,
        cms.config,
        nextBuild
      )) {
        yield { cms, db, localData: fileData };
        if (onAfterGenerate && !afterGenerateCalled) {
          afterGenerateCalled = true;
          onAfterGenerate();
        }
      }
      if (done) {
        await Promise.all([
          generatePackage(context, cms.config),
          writeStore(storeData())
        ]);
        break;
      }
    } catch (e) {
      console.error(e);
    }
  }
}
export {
  generate
};
