import "../../chunks/chunk-U5RRZUYZ.js";

// src/cli/serve/GitHistory.ts
import { JsonLoader } from "alinea/backend";
import { join } from "alinea/core/util/Paths";
var encoder = new TextEncoder();
var GitHistory = class {
  constructor(git, config, rootDir) {
    this.git = git;
    this.config = config;
    this.rootDir = rootDir;
  }
  async revisions(file) {
    const list = await this.git.log([
      "--follow",
      "--name-status",
      "--",
      join(this.rootDir, file)
    ]);
    return list.all.map((row) => {
      const parsedFile = row.diff?.files?.[0]?.file;
      const fileLocation = (
        // SimpleGit seems to mis-parse these sometimes so we try to fix it here
        parsedFile ? parsedFile.split("	").pop().trim() : file
      );
      return {
        ref: row.hash,
        createdAt: new Date(row.date).getTime(),
        description: row.message,
        file: fileLocation,
        user: {
          sub: row.author_email,
          name: row.author_name
        }
      };
    });
  }
  async revisionData(file, ref) {
    const { config } = this;
    const data = await this.git.show([`${ref}:${file}`, "--format=%B"]);
    try {
      return JsonLoader.parse(config.schema, encoder.encode(data));
    } catch (cause) {
      throw new Error(`Failed to parse revision ${ref} of ${file}`, {
        cause
      });
    }
  }
};
export {
  GitHistory
};
