import "../chunks/chunk-U5RRZUYZ.js";

// src/core/CMS.ts
import { createConfig } from "./Config.js";
import { Graph, GraphRealm } from "./Graph.js";
import { Operation, Transaction } from "./Transaction.js";
import { entries } from "./util/Objects.js";
var attached = /* @__PURE__ */ new WeakMap();
var CMS = class extends GraphRealm {
  graph;
  config;
  constructor(config) {
    const normalizedConfig = createConfig(config);
    const resolver = {
      resolve: (params) => {
        return this.resolver().then((r) => r.resolve(params));
      }
    };
    super(normalizedConfig, resolver);
    this.config = normalizedConfig;
    this.graph = new Graph(normalizedConfig, resolver);
  }
  commit(...operations) {
    return Transaction.commit(
      this,
      operations.map((op) => op[Operation.Data]).flat()
    );
  }
  #attach(config) {
    for (const [name, workspace] of entries(config.workspaces)) {
      if (attached.has(workspace))
        throw new Error(`Workspace is already attached to a CMS: ${name}`);
      attached.set(workspace, this);
      for (const [name2, root] of entries(workspace)) {
        if (attached.has(root))
          throw new Error(`Root is already attached to a CMS: ${name2}`);
        attached.set(root, this);
      }
    }
  }
  get schema() {
    return this.config.schema;
  }
  get workspaces() {
    return this.config.workspaces;
  }
};
((CMS2) => {
  function instanceFor(attachment) {
    const cms = attached.get(attachment);
    if (!cms)
      throw new Error(`No CMS attached to ${attachment}`);
    return cms;
  }
  CMS2.instanceFor = instanceFor;
})(CMS || (CMS = {}));
export {
  CMS
};
