import "../chunks/chunk-U5RRZUYZ.js";

// src/core/Schema.ts
import { Hint } from "./Hint.js";
import { Type } from "./Type.js";
import { isValidIdentifier } from "./util/Identifiers.js";
import { entries, fromEntries } from "./util/Objects.js";
var shapesCache = /* @__PURE__ */ new WeakMap();
var hintCache = /* @__PURE__ */ new WeakMap();
var Schema;
((Schema2) => {
  function validate(schema2) {
    for (const [key, type] of entries(schema2)) {
      switch (key) {
        case "Entry":
          throw new Error(`${key} is a reserved Type name`);
        default:
          if (!isValidIdentifier(key))
            throw new Error(
              `Invalid Type name "${key}", use only a-z, A-Z, 0-9, and _`
            );
          const { contains } = Type.meta(type);
          if (contains) {
            for (const name of contains) {
              if (!schema2[name])
                throw new Error(
                  `Type "${key}" contains "${name}", but that Type does not exist`
                );
            }
          }
      }
    }
  }
  Schema2.validate = validate;
  function shapes(schema2) {
    if (!shapesCache.has(schema2))
      shapesCache.set(
        schema2,
        fromEntries(
          entries(schema2).map(([key, type]) => {
            return [key, Type.shape(type)];
          })
        )
      );
    return shapesCache.get(schema2);
  }
  Schema2.shapes = shapes;
  function hint(schema2) {
    if (!hintCache.has(schema2)) {
      hintCache.set(
        schema2,
        Hint.Union(
          entries(schema2).map(([key, type]) => {
            return Type.hint(type);
          })
        )
      );
    }
    return hintCache.get(schema2);
  }
  Schema2.hint = hint;
  function targets(schema2) {
    return new Map(
      entries(schema2).map(([key, type]) => {
        return [Type.target(type), key];
      })
    );
  }
  Schema2.targets = targets;
  function typeNames(schema2) {
    return new Map(entries(schema2).map(([key, type]) => [type, key]));
  }
  Schema2.typeNames = typeNames;
})(Schema || (Schema = {}));
function schema(options) {
  return options.types ?? options;
}
export {
  Schema,
  schema
};
