import type { EntryEditProps } from 'alinea/dashboard/view/EntryEdit';
import { Callable } from 'rado/util/Callable';
import type { ComponentType } from 'react';
import { EntryPhase } from './EntryRow.js';
import { Field } from './Field.js';
import { Hint } from './Hint.js';
import { Label } from './Label.js';
import { Meta, StripMeta } from './Meta.js';
import { Section } from './Section.js';
import type { View } from './View.js';
import { Cursor } from './pages/Cursor.js';
import { Expr } from './pages/Expr.js';
import { Selection, toSelection } from './pages/ResolveData.js';
import { RecordShape } from './shape/RecordShape.js';
import { Expand } from './util/Types.js';
export interface EntryUrlMeta {
    phase: EntryPhase;
    path: string;
    parentPaths: Array<string>;
    locale?: string | null;
}
/** Optional settings to configure a Type */
export interface TypeMeta {
    /** Accepts entries of these types as children */
    contains?: Array<string>;
    /** @deprecated Use contains instead */
    isContainer?: true;
    /** @deprecated Use hidden instead */
    isHidden?: true;
    /** Entries do not show up in the sidebar content tree */
    hidden?: true;
    /** An icon (React component) to represent this type in the dashboard */
    icon?: ComponentType;
    /** A React component used to view an entry of this type in the dashboard */
    view?: ComponentType<EntryEditProps & {
        type: Type;
    }>;
    /** A React component used to view a row of this type in the dashboard */
    summaryRow?: View<any>;
    /** A React component used to view a thumbnail of this type in the dashboard */
    summaryThumb?: View<any>;
    /** Create indexes on fields of this type */
    entryUrl?: (meta: EntryUrlMeta) => string;
}
export interface TypeData {
    label: Label;
    shape: RecordShape;
    hint: Hint;
    definition: TypeDefinition;
    meta: TypeMeta;
    sections: Array<Section>;
    target: TypeTarget;
}
export declare class TypeTarget {
}
export declare class TypeI<Definition = object> {
    get [Type.Data](): TypeData;
    [toSelection](): Selection.Row;
}
export interface TypeI<Definition = object> extends Callable {
    (): Cursor.Find<TypeRow<Definition>>;
    (partial: Partial<TypeRow<Definition>>): Cursor.Typed<Definition>;
}
export type Type<Definition = object> = Definition & TypeI<Definition>;
type TypeRow<Definition> = Expand<{
    [K in keyof Definition as Definition[K] extends Expr<any> ? K : never]: Definition[K] extends Expr<infer T> ? T : never;
}>;
export declare namespace Type {
    type Infer<Definition> = TypeRow<Definition>;
    const Data: unique symbol;
    function label(type: Type): Label;
    function meta(type: Type): TypeMeta;
    function isHidden(type: Type): boolean;
    function shape(type: Type): RecordShape;
    function toV1(type: Type, value: any): any;
    function searchableText(type: Type, value: any): string;
    function fields(type: Type): Record<string, Field>;
    function hint(type: Type): Hint;
    function sections(type: Type): Section[];
    function isContainer(type: Type): boolean;
    function target(type: Type): TypeTarget;
    function field(type: Type, name: string): Field | undefined;
    function isType(type: any): type is Type;
    function sharedData(type: Type, entryData: Record<string, unknown>): Record<string, unknown> | undefined;
    function validate(type: Type): void;
}
export interface TypeDefinition {
    [key: string]: Field<any, any> | Section;
    readonly [Meta]?: TypeMeta;
}
export interface TypeFields {
    [key: string]: Field<any, any> | Section;
}
export interface TypeOptions<Definition> extends TypeMeta {
    fields: Definition;
}
export declare function parseTypeParams<Definition>(definition: TypeOptions<Definition> | Definition): {
    definition: Definition;
    options: TypeMeta;
};
/** Create a new type */
export declare function type<Definition extends TypeFields>(definition: TypeOptions<Definition>): Type<Definition>;
export declare function type<Definition extends TypeFields>(label: string, definition: TypeOptions<Definition>): Type<Definition>;
/** @deprecated See https://github.com/alineacms/alinea/issues/373 */
export declare function type<Definition extends TypeDefinition>(definition: Definition): Type<StripMeta<Definition>>;
/** @deprecated See https://github.com/alineacms/alinea/issues/373 */
export declare function type<Definition extends TypeDefinition>(label: string, definition: Definition): Type<StripMeta<Definition>>;
export declare namespace type {
    const meta: typeof Meta;
}
export {};
