import {
  PLazy
} from "../../chunks/chunk-IKINPSS5.js";
import "../../chunks/chunk-U5RRZUYZ.js";

// src/core/driver/DefaultDriver.server.tsx
import { Database } from "alinea/backend";
import { createStore } from "alinea/backend/Store";
import { EntryResolver } from "alinea/backend/resolver/EntryResolver";
import { createCloudHandler } from "alinea/cloud/server/CloudHandler";
import { CMS } from "../CMS.js";
import { Client } from "../Client.js";
import { Realm } from "../pages/Realm.js";
import { base64 } from "../util/Encoding.js";
import { Logger } from "../util/Logger.js";
var store = PLazy.from(async () => {
  const { storeData } = await import("@alinea/generated/store.js");
  return createStore(new Uint8Array(base64.parse(storeData)));
});
var DefaultDriver = class extends CMS {
  apiKey = process.env.ALINEA_API_KEY;
  db = PLazy.from(async () => new Database(this.config, await store));
  cloudHandler = PLazy.from(async () => {
    const db = await this.db;
    return createCloudHandler(this.config, db, this.apiKey);
  });
  async resolver() {
    const devUrl = process.env.ALINEA_DEV_SERVER;
    if (devUrl)
      return new Client({
        config: this.config,
        url: devUrl,
        resolveDefaults: {
          syncInterval: this.config.syncInterval ?? 60,
          realm: Realm.Published
        }
      });
    return new EntryResolver(await this.db, this.config.schema);
  }
  async connection() {
    const devUrl = process.env.ALINEA_DEV_SERVER;
    if (devUrl)
      return new Client({ config: this.config, url: devUrl });
    return (await this.cloudHandler).connect({
      logger: new Logger("driver")
    });
  }
};
function createCMS(config) {
  return new DefaultDriver(config);
}
export {
  DefaultDriver,
  createCMS
};
