"use server";
import {
  enums,
  object,
  string
} from "../../chunks/chunk-7LBNER34.js";
import "../../chunks/chunk-U5RRZUYZ.js";

// src/core/driver/NextDriver.server.tsx
import { JWTPreviews } from "alinea/backend";
import { parseChunkedCookies } from "alinea/preview/ChunkCookieValue";
import {
  PREVIEW_ENTRYID_NAME,
  PREVIEW_PHASE_NAME,
  PREVIEW_UPDATE_NAME
} from "alinea/preview/PreviewConstants";
import dynamic from "next/dynamic.js";
import { Suspense } from "react";
import { Client } from "../Client.js";
import { Entry } from "../Entry.js";
import { outcome } from "../Outcome.js";
import { createSelection } from "../pages/CreateSelection.js";
import { Realm } from "../pages/Realm.js";
import { DefaultDriver } from "./DefaultDriver.server.js";
import { jsx } from "react/jsx-runtime";
var SearchParams = object({
  token: string,
  entryId: string,
  realm: enums(Realm)
});
var PREVIEW_TOKEN = "alinea-preview-token";
var NextDriver = class extends DefaultDriver {
  apiKey = process.env.ALINEA_API_KEY;
  jwtSecret = this.apiKey || "dev";
  async user() {
    const { cookies, draftMode } = await import("next/headers.js");
    const [draftStatus] = outcome(() => draftMode());
    const isDraft = draftStatus?.isEnabled;
    if (!isDraft)
      return null;
    const token = cookies().get(PREVIEW_TOKEN)?.value;
    if (!token)
      return null;
    const previews = new JWTPreviews(this.jwtSecret);
    const payload = await previews.verify(token);
    if (!payload)
      return null;
    return payload;
  }
  async getDefaults() {
    const { cookies, draftMode } = await import("next/headers.js");
    const [draftStatus] = outcome(() => draftMode());
    const isDraft = draftStatus?.isEnabled;
    const resolveDefaults = {
      syncInterval: this.config.syncInterval ?? 60,
      realm: Realm.Published
    };
    if (isDraft) {
      resolveDefaults.realm = Realm.PreferDraft;
      const update = parseChunkedCookies(
        PREVIEW_UPDATE_NAME,
        cookies().getAll()
      );
      if (update) {
        const entryIdCookie = cookies().get(PREVIEW_ENTRYID_NAME);
        const phaseCookie = cookies().get(PREVIEW_PHASE_NAME);
        const entryId = entryIdCookie?.value;
        const phase = phaseCookie?.value;
        if (entryId && phase)
          resolveDefaults.preview = { entryId, phase, update };
      }
    }
    return resolveDefaults;
  }
  async resolver() {
    const resolveDefaults = await this.getDefaults();
    const devUrl = process.env.ALINEA_DEV_SERVER;
    if (devUrl)
      return new Client({
        config: this.config,
        url: devUrl,
        resolveDefaults
      });
    const handler = await this.cloudHandler;
    return {
      resolve(params) {
        return handler.resolve({ ...resolveDefaults, ...params });
      }
    };
  }
  backendHandler = async (request) => {
    const handler = await this.cloudHandler;
    const response = await handler.router.handle(request);
    return response ?? new Response("Not found", { status: 404 });
  };
  previewHandler = async (request) => {
    const { draftMode, cookies } = await import("next/headers.js");
    const { searchParams } = new URL(request.url);
    const params = SearchParams({
      token: searchParams.get("token"),
      entryId: searchParams.get("entryId"),
      realm: searchParams.get("realm")
    });
    const previews = new JWTPreviews(this.jwtSecret);
    await previews.verify(params.token);
    cookies().set(PREVIEW_TOKEN, params.token);
    if (!searchParams.has("full")) {
      cookies().delete(PREVIEW_UPDATE_NAME);
      cookies().delete(PREVIEW_ENTRYID_NAME);
      cookies().delete(PREVIEW_PHASE_NAME);
    }
    const cnx = await this.resolver();
    const resolveDefaults = await this.getDefaults();
    const url = await cnx.resolve({
      ...resolveDefaults,
      selection: createSelection(
        Entry({ entryId: params.entryId }).select(Entry.url).first()
      )
    });
    if (!url)
      return new Response("Not found", { status: 404 });
    const source = new URL(request.url);
    if (source.hostname === "0.0.0.0")
      source.hostname = "localhost";
    const location = new URL(url, source.origin);
    draftMode().enable();
    return new Response(`Redirecting...`, {
      status: 302,
      headers: { location: location.toString() }
    });
  };
  previews = async ({
    widget,
    workspace,
    root
  }) => {
    const { draftMode } = await import("next/headers.js");
    const [draftStatus] = outcome(() => draftMode());
    const isDraft = draftStatus?.isEnabled;
    if (!isDraft)
      return null;
    const user = await this.user();
    const NextPreviews = dynamic(
      () => import("alinea/core/driver/NextPreviews"),
      { ssr: false }
    );
    const devUrl = process.env.ALINEA_DEV_SERVER;
    const dashboardUrl = devUrl ?? this.config.dashboard?.dashboardUrl ?? "/admin.html";
    return /* @__PURE__ */ jsx(Suspense, { children: user && /* @__PURE__ */ jsx(
      NextPreviews,
      {
        widget,
        user,
        dashboardUrl,
        workspace,
        root
      }
    ) });
  };
};
function createNextCMS(config) {
  return new NextDriver(config);
}
export {
  createNextCMS
};
