import {
  connect
} from "../../chunks/chunk-LMUDRU2U.js";
import "../../chunks/chunk-FLZ4KUMA.js";
import "../../chunks/chunk-4JLFL6LD.js";
import "../../chunks/chunk-U5RRZUYZ.js";

// src/core/driver/TestDriver.ts
import sqlite from "@alinea/sqlite-wasm";
import { Database, Handler, JWTPreviews } from "alinea/backend";
import { CMS } from "../CMS.js";
import { createId } from "../Id.js";
import { Logger } from "../util/Logger.js";
var TestDriver = class extends CMS {
  store = sqlite().then(
    ({ Database: Database2 }) => connect(new Database2()).toAsync()
  );
  db = this.store.then(async (store) => {
    const db = new Database(this.config, store);
    await db.fill({ async *entries() {
    } }, "");
    return db;
  });
  handler = this.db.then(async (db) => {
    return new Handler({
      config: this.config,
      db,
      previews: new JWTPreviews("test"),
      previewAuthToken: "test",
      target: {
        mutate: async ({ mutations }) => {
          return { commitHash: createId() };
        }
      },
      media: {
        async prepareUpload(file) {
          const id = createId();
          const serve = await listenForUpload();
          return {
            entryId: createId(),
            location: `media/${file}_${id}`,
            previewUrl: `media/${file}_${id}`,
            upload: {
              url: serve.url
            }
          };
        }
      }
    });
  });
  cnx = this.handler.then(
    (handler) => handler.connect({ logger: new Logger("test") })
  );
  connection = () => this.cnx;
  resolver = () => this.cnx;
};
function createTestCMS(config) {
  return new TestDriver(config);
}
async function listenForUpload() {
  const { createServer } = await import("http");
  const server = createServer((req, res) => {
    res.end();
    server.close();
  });
  return new Promise((resolve) => {
    server.listen(0, () => {
      resolve({
        url: `http://localhost:${server.address().port}`
      });
    });
  });
}
export {
  createTestCMS
};
