import "../../chunks/chunk-U5RRZUYZ.js";

// src/dashboard/editor/InputForm.tsx
import { Field } from "alinea/core/Field";
import { Section } from "alinea/core/Section";
import { Type } from "alinea/core/Type";
import { entries } from "alinea/core/util/Objects";
import { useFieldOptions } from "alinea/dashboard/editor/UseField";
import { Lift } from "alinea/ui/Lift";
import { VStack } from "alinea/ui/Stack";
import { FormProvider } from "../atoms/FormAtoms.js";
import { ErrorBoundary } from "../view/ErrorBoundary.js";
import { jsx, jsxs } from "react/jsx-runtime";
function InputForm(props) {
  const type = props.type ?? props.form.type;
  const inner = /* @__PURE__ */ jsx(VStack, { gap: 20, children: Type.sections(type).map((section, i) => {
    const View = Section.view(section);
    if (View)
      return /* @__PURE__ */ jsx(View, { section }, i);
    return /* @__PURE__ */ jsx("div", { style: { display: "contents" }, children: /* @__PURE__ */ jsx(Fields, { fields: Section.fields(section), border: props.border }) }, i);
  }) });
  if (!props.form)
    return inner;
  return /* @__PURE__ */ jsx(FormProvider, { form: props.form, children: inner });
}
function Fields({ fields, border = true }) {
  const inner = entries(fields).map(([name, field]) => {
    return /* @__PURE__ */ jsx(InputField, { field }, name);
  });
  if (inner.length === 0)
    return null;
  return border ? /* @__PURE__ */ jsx(Lift, { children: inner }) : /* @__PURE__ */ jsx("div", { children: inner });
}
function MissingView({ field }) {
  return /* @__PURE__ */ jsxs("div", { children: [
    "Missing view for field: ",
    Field.label(field)
  ] });
}
function InputField({ field }) {
  const View = field[Field.Data].view;
  const options = useFieldOptions(field);
  if (!View)
    return /* @__PURE__ */ jsx(MissingView, { field });
  if (options.hidden)
    return null;
  return /* @__PURE__ */ jsx(ErrorBoundary, { children: /* @__PURE__ */ jsx(View, { field }) });
}
export {
  Fields,
  InputField,
  InputForm,
  MissingView
};
