import {
  useAtomValue,
  useSetAtom
} from "../../chunks/chunk-WF77DMLN.js";
import "../../chunks/chunk-OBOPLPUQ.js";
import "../../chunks/chunk-U5RRZUYZ.js";

// src/dashboard/editor/UseField.tsx
import { useCallback, useEffect, useMemo } from "react";
import { useFormContext } from "../atoms/FormAtoms.js";
function useField(field) {
  const atoms = useFormContext();
  const actual = typeof field === "string" ? atoms.fieldByKey(field) : field;
  const fieldKey = useFieldKey(actual);
  const value = useFieldValue(actual);
  const mutator = useFieldMutator(actual);
  const options = useFieldOptions(actual);
  const error = useFieldError(actual);
  return {
    fieldKey,
    label: options.label,
    options,
    value,
    mutator,
    error
  };
}
function useFieldKey(field) {
  const atoms = useFormContext();
  const key = atoms.keyOf(field);
  return key;
}
function useFieldOptions(field) {
  const atoms = useFormContext();
  const atom = atoms.fieldInfo(field);
  return useAtomValue(atom.options);
}
function useFieldError(field) {
  const atoms = useFormContext();
  const setError = useSetAtom(atoms.errors);
  const value = useFieldValue(field);
  const options = useFieldOptions(field);
  const key = useFieldKey(field);
  const fieldPath = atoms.path + "." + key;
  const hasError = useCallback(
    (value2) => {
      if (options.validate) {
        const validates = options.validate(value2);
        if (typeof validates === "boolean")
          return !validates;
        return validates;
      }
      const isRequired = options.required;
      const isEmpty = value2 === void 0 || value2 === null || value2 === "" || Array.isArray(value2) && value2.length === 0;
      if (isRequired && isEmpty)
        return true;
    },
    [options]
  );
  const error = useMemo(() => {
    return hasError(value);
  }, [hasError, value]);
  useEffect(() => {
    setError(fieldPath, field, error);
  }, [setError, fieldPath, field, error]);
  return error;
}
function useFieldValue(field) {
  const atoms = useFormContext();
  const atom = atoms.fieldInfo(field);
  return useAtomValue(atom.value);
}
function useFieldMutator(field) {
  const atoms = useFormContext();
  const atom = atoms.fieldInfo(field);
  return atom.mutator;
}
export {
  useField,
  useFieldError,
  useFieldKey,
  useFieldMutator,
  useFieldOptions,
  useFieldValue
};
